@@ -57,7 +57,8 @@ static int is_parent_of(pdl *it,pdl_trans *trans) {
 pdl *pdl_null() {
 	PDL_Indx d[1] = {0};
 	pdl *it = pdl_new();
-	pdl_makescratchhash(it,0.0,PDL_B);
+	PDL_Anyval zero = { PDL_B, 0 };
+	pdl_makescratchhash(it, zero);
 	pdl_setdims(it,d,1);
 	it->state |= PDL_NOMYDIMS;
 	return it;
@@ -143,7 +144,7 @@ pdl* pdl_create(int type) {
      it->magic = 0;
      it->hdrsv = 0;
 
-     PDLDEBUG_f(printf("CREATE %p\n",(void*)it));
+     PDLDEBUG_f(printf("CREATE %p (size=%d)\n",(void*)it,sizeof(pdl)));
      return it;
 }
 
@@ -419,7 +420,7 @@ void pdl_dump_flags_fixspace(int flags, int nspac, int type)
 	printf("\n");
 }
 
-/* Dump a tranformation (don't dump the pdls, just pointers to them */
+/* Dump a transformation (don't dump the pdls, just pointers to them */
 void pdl_dump_trans_fixspace (pdl_trans *it, int nspac) {
 	int i;
 	char spaces[PDL_MAXSPACE];
@@ -461,7 +462,7 @@ void pdl_dump_trans_fixspace (pdl_trans *it, int nspac) {
 void pdl_dump_fixspace(pdl *it,int nspac)
 {
 	PDL_DECL_CHILDLOOP(it)
-	int i;
+	PDL_Indx i;
 	char spaces[PDL_MAXSPACE];
 	if (nspac >= PDL_MAXSPACE) {
 	  printf("too many spaces requested: %d"
@@ -496,7 +497,7 @@ void pdl_dump_fixspace(pdl *it,int nspac)
 	if(it->state & PDL_ALLOCATED) {
 		printf(")\n%s   First values: (",spaces);
 		for(i=0; i<it->nvals && i<10; i++) {
-			printf("%s%f",(i?" ":""),pdl_get_offs(it,i));
+                       printf("%s%f",(i?" ":""),pdl_get_offs(it,i).value.D);
 		}
 	} else {
 		printf(")\n%s   (not allocated",spaces);
@@ -1402,11 +1403,11 @@ void pdl_make_physvaffine(pdl *it)
 	pdl_trans_affine *at;
 	pdl *parent;
 	pdl *current;
-	int *incsleft = 0;
+	PDL_Indx *incsleft = 0;
 	int i,j;
 	PDL_Indx inc;
 	PDL_Indx newinc;
-	int ninced;
+	PDL_Indx ninced;
 	int flag;
 	int incsign;
 
@@ -1436,17 +1437,17 @@ void pdl_make_physvaffine(pdl *it)
 	t=it->trans;
 	current = it;
 	while(t && (t->flags & PDL_ITRANS_ISAFFINE)) {
-		int cur_offset = 0;
+		PDL_Indx cur_offset = 0;
 		at = (pdl_trans_affine *)t;
 		parent = t->pdls[0];
 		/* For all dimensions of the childest piddle */
 		for(i=0; i<it->ndims; i++) {
-			int offset_left = it->vafftrans->offs;
+			PDL_Indx offset_left = it->vafftrans->offs;
 
 			/* inc = the increment at the current stage */
 			inc = it->vafftrans->incs[i];
 			incsign = (inc >= 0 ? 1:-1);
-			inc= abs(inc);
+			inc *= incsign;
 			newinc = 0;
 			/* For all dimensions of the current piddle */
 			for(j=current->ndims-1; j>=0 && current->dimincs[j] != 0; j--) {
@@ -1462,7 +1463,7 @@ void pdl_make_physvaffine(pdl *it)
 					ninced = inc / current->dimincs[j];
 					if(cur_offset + it->dims[i]*ninced >
 						current->dims[j]) {
-					  int foo=
+					  PDL_Indx foo =
 					   (cur_offset + it->dims[i]*ninced)*
 					   current->dimincs[j];
 					  int k;
@@ -1496,7 +1497,7 @@ void pdl_make_physvaffine(pdl *it)
 			it->vafftrans->incs[i] = incsleft[i];
 		}
 		{
-			int offset_left = it->vafftrans->offs;
+			PDL_Indx offset_left = it->vafftrans->offs;
 			inc = it->vafftrans->offs;
 			newinc = 0;
 			for(j=current->ndims-1; j>=0 && current->dimincs[j] != 0; j--) {
